# encoding: utf-8
"""
Вспомогательные функции. Конфигурация скрипта.
"""
import json
import os
import platform

from .messages import print_error_and_exit


def get_config_path():
    """
    Получить путь до папки с конфигами.

    :return: Путь до папки с конфигами
    :rtype: str
    """
    if platform.system() in ('Linux', 'Darwin'):
        return os.path.join(os.environ['HOME'], '.config', 'bars_csw')
    if platform.system() == 'Windows':
        return os.path.join(os.getenv('APPDATA'), 'bars_csw')

    print_error_and_exit('Система не поддерживается')
    return None


def get_config():  # pylint: disable=inconsistent-return-statements
    """
    Получить распарсеный общий конфиг.

    :return: Словарь с данными конфигурации
    :rtype: dict
    """
    json_file_path = os.path.join(get_config_path(), 'csw.json')

    try:
        with open(json_file_path, encoding='utf-8') as file:
            config = json.load(file)

        return config
    except FileNotFoundError:
        print_error_and_exit(
            'Не обнаружен файл конфигурации.\n'
            'Выполните команду "csw --config" и переместите файл csw.json '
            'в открывшуюся директорию'
        )


def open_config_in_file_manager():
    """
    Открыть папку с конфигами в файловом менеджере.
    """
    config_path = get_config_path()

    if not os.path.exists(config_path):
        os.makedirs(config_path, exist_ok=True)

    if platform.system() == 'Linux':
        os.system('xdg-open "{}" &> /dev/null'.format(config_path))  # noqa
    elif platform.system() == 'Windows':
        os.system('explorer "{}"'.format(config_path))  # noqa: S605
    elif platform.system() == 'Darwin':
        os.system('open "{}"'.format(config_path))  # noqa: S605
    else:
        print_error_and_exit('Система не поддерживается')
